/*
 * Copyright (c) Members of the EGEE Collaboration. 2004. See
 * http://www.eu-egee.org/partners/ for details on the copyright holders.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package org.glite.security.delegation;

import org.apache.log4j.Appender;
import org.apache.log4j.ConsoleAppender;
import org.apache.log4j.Layout;
import org.apache.log4j.Level;
import org.apache.log4j.Logger;
import org.apache.log4j.PatternLayout;

import org.glite.security.delegation.DelegationHandler;
import org.glite.security.delegation.GrDPX509Util;
import org.glite.security.delegation.impl.GliteDelegation;

import java.net.URL;

import java.util.Random;


/*
 * Simple sample client side of delegation process
 */
public class ClientDelegation {
    public static void main(String[] args) throws Exception {
        
        Logger logger = Logger.getLogger(ClientDelegation.class);
        String location = args[1];
        String delegationID = args[0];

        // We overwrite you delegationID to be ensure about its uniqness
        
        Random generator = new Random();
        int rnd = generator.nextInt(65000);
        delegationID = Integer.toString(rnd);

        logger.debug( "Service Locatio : "+ location);
        logger.debug( "DelegationID : "+ delegationID);

        URL endPoint = new URL(args[1]);

        org.glite.security.delegation.service.DelegationService service = new org.glite.security.delegation.service.DelegationServiceLocator();
        org.glite.security.delegation.service.Delegation dlg = service.getGridsiteDelegation(endPoint);

        String pkc10ReqCert = null;

        pkc10ReqCert = dlg.getProxyReq(delegationID);
        
//        System.out.println("req is: " + pkc10ReqCert);
        
        if (pkc10ReqCert != null) {
        	String propfile = GrDPX509Util.getDlgorPropertyFile();
            logger.debug("propfile is: " + propfile);
        												
//            Logger LOGGERRoot = Logger.getLogger("org.glite.security.delegation");
//            Layout lay = new PatternLayout("%d{ISO8601} %-5p [%t] %c{2}%l %x - %m%n");
//            Appender appender = new ConsoleAppender(lay);
//            LOGGERRoot.addAppender(appender);
//            LOGGERRoot.setLevel(Level.DEBUG);
//            Logger utilLogger = Logger.getLogger("org.glite.security.util");
//            utilLogger.setLevel(Level.OFF);
            
            DelegationHandler dlgHandler = new DelegationHandler(pkc10ReqCert,
                    delegationID, propfile);
            String proxy = dlgHandler.getPEMProxyCertificate();
//            System.out.println("proxy is: " + proxy);
            
            if(proxy == null){
            	throw new RuntimeException("Failed to generate proxy.");
            }
            
            dlg.putProxy(delegationID, proxy);
            logger.debug("Certificate Request \n" + pkc10ReqCert);
        } else {
            logger.error("Error, Service refused to perform delegation");
            System.exit(0);
        }
    }
}
